Files
rocm-systems/projects/clr/hipamd/tests/src/hipCKernel.c
T
Maneesh Gupta 43d07079e9 directed tests: Updated to use new hip include path
Change-Id: Iab1aee638b7158eb9674a19625dedf6471947e51


[ROCm/clr commit: 5947878247]
2016-10-04 22:20:50 +05:30

20 lines
436 B
C

#include "hip/hip_runtime.h"
#include "hip/hip_runtime_api.h"
__global__ void Kernel(hipLaunchParm lp, float *Ad){
int tx = hipThreadIdx_x + hipBlockIdx_x * hipBlockDim_x;
}
int main(){
dim3 dimBlock;
dim3 dimGrid;
dimGrid.x = 1;
dimGrid.y = 1;
dimGrid.z = 1;
dimBlock.x = 1;
dimBlock.y = 1;
dimBlock.z = 1;
float *A;
hipLaunchKernel(HIP_KERNEL_NAME(Kernel), dimGrid, dimBlock, 0, 0, A);
}